@@ -288,11 +288,11 @@ updateAccordion <- function(id, selected, session = shiny::getDefaultReactiveDom
 #'        id = "mycarousel",
 #'        carouselItem(
 #'         caption = "Item 1",
-#'         tags$img(src = "https://placehold.it/900x500/3c8dbc/ffffff&text=I+Love+Bootstrap")
+#'         tags$img(src = "https://via.placeholder.com/500")
 #'        ),
 #'        carouselItem(
 #'         caption = "Item 2",
-#'         tags$img(src = "https://placehold.it/900x500/39CCCC/ffffff&text=I+Love+Bootstrap")
+#'         tags$img(src = "https://via.placeholder.com/500")
 #'        )
 #'       )
 #'      ),
@@ -846,8 +846,8 @@ bs4Loading <- function() {
 #'         title = "Item 3",
 #'         icon = icon("paint-brush"),
 #'         status = "orange",
-#'         timelineItemMedia(image = "http://placehold.it/150x100"),
-#'         timelineItemMedia(image = "http://placehold.it/150x100")
+#'         timelineItemMedia(image = "https://via.placeholder.com/150x100"),
+#'         timelineItemMedia(image = "https://via.placeholder.com/150x100")
 #'        ),
 #'        timelineStart(color = "secondary")
 #'       )
@@ -994,7 +994,7 @@ bs4TimelineItem <- function(..., icon = NULL,
       #timelineItem time/date
       shiny::tags$span(
         class = "time",
-        shiny::icon("clock-o"),
+        shiny::icon("clock"),
         time
       ),
       
@@ -1051,7 +1051,7 @@ bs4TimelineItemMedia <- function(image = NULL, height = NULL, width = NULL) {
 #'
 #' \link{timelineStart} indicates a starting point.
 #'
-#' @param icon Item icon such as "clock-o", "times", ...
+#' @param icon Item icon such as "clock", "times", ...
 #' @param color Item color. Valid colors are defined as follows:
 #' \itemize{
 #'   \item \code{primary}: \Sexpr[results=rd, stage=render]{bs4Dash:::rd_color_tag("#007bff")}.
@@ -1079,7 +1079,7 @@ bs4TimelineItemMedia <- function(image = NULL, height = NULL, width = NULL) {
 #' @rdname timeline
 #' 
 #' @export
-bs4TimelineStart <- function(icon = shiny::icon("clock-o"), color = NULL) {
+bs4TimelineStart <- function(icon = shiny::icon("clock"), color = NULL) {
   
   iconTag <- icon
   if (!is.null(color)) {
@@ -1095,7 +1095,7 @@ bs4TimelineStart <- function(icon = shiny::icon("clock-o"), color = NULL) {
 #'
 #' \link{timelineEnd} indicates an end point.
 #'
-#' @param icon Item icon such as "clock-o", "times", ...
+#' @param icon Item icon such as "clock", "times", ...
 #' @param color Item color. Valid colors are defined as follows:
 #' \itemize{
 #'   \item \code{primary}: \Sexpr[results=rd, stage=render]{bs4Dash:::rd_color_tag("#007bff")}.
@@ -1265,7 +1265,7 @@ bs4Stars <- function(value, max = 5, color = "warning") {
 #'       "It uses utility classes for typography and spacing 
 #'       to space content out within the larger container.",
 #'       status = "primary",
-#'       href = "http://www.google.fr"
+#'       href = "https://www.google.com"
 #'       )
 #'      )
 #'    ),
@@ -1347,19 +1347,19 @@ bs4Jumbotron <- function(..., title = NULL, lead = NULL, href = NULL, btnName =
 #'          "Cras justo odio",
 #'          active = TRUE, 
 #'          disabled = FALSE, 
-#'          href = "http://www.google.fr"
+#'          href = "https://www.google.com"
 #'         ),
 #'         listGroupItem(
 #'          active = FALSE, 
 #'          disabled = FALSE, 
 #'          "Dapibus ac facilisis in",
-#'          href = "http://www.google.fr"
+#'          href = "https://www.google.com"
 #'         ),
 #'         listGroupItem(
 #'          "Morbi leo risus",
 #'          active = FALSE, 
 #'          disabled = TRUE, 
-#'          href = "http://www.google.fr"
+#'          href = "https://www.google.com"
 #'         )
 #'        ),
 #'        listGroup(
@@ -1566,7 +1566,7 @@ ionicon <- function(name) {
 #'      box(
 #'       title = "attachmentBlock example",
 #'       attachmentBlock(
-#'        image = "https://adminlte.io/themes/AdminLTE/dist/img/photo1.png",
+#'        image = "https://adminlte.io/themes/v3/dist/img/user1-128x128.jpg",
 #'        title = "Test",
 #'        href = "https://google.com",
 #'        "This is the content"
@@ -2434,7 +2434,7 @@ userPost <- function(..., id = NULL, image, author,
   items <- list(...)
   items <- lapply(seq_along(items), function(i) {
     # do not apply to other things than tags
-    if (class(items[[i]]) == "shiny.tag") {
+    if (inherits(items[[i]], "shiny.tag")) {
       if (items[[i]]$name == "img") {
         # wrap the image item in a div to align its content
         shiny::tags$div(
